# robotjes-client

The [robotjes-client](https://github.com/Janvanoorschot/robotjes-client) package
supports development of robot software for the 
[Robomind Academy Python Course](https://www.robomindacademy.com/navigator/storylines?course=RoboPython).

On the one hand it containes a full maze simulation so the student
can develop robot software completely locally.
On the other hand it contains a *requests* based REST module that 
allows communication with the Robomind Academy servers and participate
in online mazes.

